@@ -1,13 +1,19 @@
-test_df <- data.frame(char = letters[1:3], dbl = c(1.1, 2.2, 3.3),
-                      int = c(1L, 2L, 3L), fct = factor(LETTERS[4:6]),
-                      ord = ordered(LETTERS[7:9], levels = rev(LETTERS[7:9])),
-                      date = as.Date(c("2016-01-25", "2017-01-27", "1979-03-09")),
-                      posix_ct = as.POSIXct(c("2016-01-25 11:25:03",
-                                              "2017-01-27 23:24:56",
-                                              "1979-03-09 10:25:15")),
-                      "column 6" = 1:3,
-                      stringsAsFactors = FALSE,
-                      check.names = FALSE)
+test_df <- data.frame(
+  char = letters[1:3],
+  dbl = c(1.1, 2.2, 3.3),
+  int = c(1L, 2L, 3L),
+  fct = factor(LETTERS[4:6]),
+  ord = ordered(LETTERS[7:9], levels = rev(LETTERS[7:9])),
+  date = as.Date(c("2016-01-25", "2017-01-27", "1979-03-09")),
+  posix_ct = as.POSIXct(c(
+    "2016-01-25 11:25:03",
+    "2017-01-27 23:24:56",
+    "1979-03-09 10:25:15"
+  )),
+  "column 6" = 1:3,
+  stringsAsFactors = FALSE,
+  check.names = FALSE
+)
 
 test_that("Restore column works", {
   cls <- col_classes(test_df)
@@ -15,9 +21,19 @@ test_that("Restore column works", {
   expect_equal(length(cls), ncol(test_df))
 
   back_in <- fromJSON(toJSON(test_df))
-  expect_equal(unname(sapply(back_in, class)),
-               c("character", "numeric", "integer", "character", "character",
-                 "character", "character", "integer"))
+  expect_equal(
+    unname(sapply(back_in, class)),
+    c(
+      "character",
+      "numeric",
+      "integer",
+      "character",
+      "character",
+      "character",
+      "character",
+      "integer"
+    )
+  )
   restored <- restore_classes(df = back_in, classes = cls)
   expect_equal(lapply(test_df, class), lapply(restored, class))
   expect_equal(names(test_df), names(restored)) # retain special names, https://github.com/ateucher/rmapshaper/issues/91
@@ -26,14 +42,6 @@ test_that("Restore column works", {
   expect_error(col_classes(test_df), "POSIXlt classes not supported")
 })
 
-test_that("Restore columns works with rmapshaperid column", {
-  df <- data.frame(a = "foo", rmapshaperid = 1L, stringsAsFactors = FALSE)
-  cls <- col_classes(df)
-  expect_equal(names(restore_classes(df, cls)), "a")
-  expect_equal(names(restore_classes(df[, 1, drop = FALSE], cls[1])), "a")
-  expect_equal(names(restore_classes(df[, 2, drop = FALSE], cls[2])), "rmapshaperid")
-})
-
 test_that("dealing with encoding works", {
   test_name <- "örtchen"
   test_value <- "Münster"
@@ -48,7 +56,6 @@ test_that("dealing with encoding works", {
   expect_equal(out[1][[1]], test_value)
   expect_equal(names(out), test_name)
 
-
   out <- GeoJSON_to_sf(pts)
   expect_s3_class(out, "sf")
   expect_equal(out[1][[1]], test_value)
@@ -76,12 +83,14 @@ test_that("NA values dealt with in sf_to_GeoJSON and GeoJSON_to_sf", {
 })
 
 test_that("utilities for checking v8 engine work", {
-  expect_type(check_v8_major_version(), "integer")
+  expect_s3_class(v8_version(), "numeric_version")
 })
 
 
 test_that("an sf data frame with no columns works", {
-  points <- geojsonsf::geojson_sf("{\"type\":\"FeatureCollection\",\"features\":[{\"type\":\"Feature\",\"properties\":{},\"geometry\":{\"type\":\"Point\",\"coordinates\":[53.7702,-40.4873]}},{\"type\":\"Feature\",\"properties\":{},\"geometry\":{\"type\":\"Point\",\"coordinates\":[58.0202,-43.634]}}]}")
+  points <- geojsonsf::geojson_sf(
+    "{\"type\":\"FeatureCollection\",\"features\":[{\"type\":\"Feature\",\"properties\":{},\"geometry\":{\"type\":\"Point\",\"coordinates\":[53.7702,-40.4873]}},{\"type\":\"Feature\",\"properties\":{},\"geometry\":{\"type\":\"Point\",\"coordinates\":[58.0202,-43.634]}}]}"
+  )
   expect_silent(ms_sf(points, "-info"))
   expect_true(grepl("\"type\":\"FeatureCollection\"", sf_to_GeoJSON(points)))
 })
@@ -117,4 +126,4 @@ test_that("ms_de_unit works", {
   expect_true(inherits(df$Sepal.Length, "units"))
   expect_warning(out <- ms_de_unit(df), "units")
   expect_false(any(vapply(out, inherits, "units", FUN.VALUE = logical(1))))
-})
\ No newline at end of file
+})
